function I = assemblyCurrent(xc, alphac, alphau, betac, betau, ...
    NBF, BFtoBFc, BFtoBFu)
%% converts controllable variable to the original vector
% This function converts controllable variables in vector xc to the 
% original vector of variables I. The transformation relation is defined 
% as I = [alphac; alphau] + [betac; betau]*xc
%
% INPUTS
%  xc: control variable, double [NBFc x 1]
%  alphac, alphau: controllable and uncontrollable parts of vector alpha,
%  double [NBFc x 1] and  [NBFu x 1]
%  betac, betau: controllable and uncontrollable parts of matrix beta,
%  double [NBFc x NBFc] and  [NBFu x NBFc]
%  NBF: total number of basis functions, integer [1 x 1]
%  BFtoBFc: vector of indices of controllable basis functions, 
%           integer [1 x NBFc]
%  BFtoBFu: vector of indices of uncontrollable basis functions, 
%           integer [1 x NBFu]
%
% OUTPUTS
%  I: vector of original variables, double [NBF x 1]
%
% SYNTAX
%
% [I] = assemblyCurrent(xc, alphac, alphau, betac, betau, ...
%    NBF, BFtoBFc, BFtoBFu)
%     
% Included in AToM, info@antennatoolbox.com
% (c) 2020, Lukas Jelinek, CTU in Prague, lukas.jelinek@antennatoolbox.com
% mcode

I = zeros(NBF,1);
I(BFtoBFc, 1) = alphac + betac*xc;
I(BFtoBFu, 1) = alphau + betau*xc;

end