function [Mcc, Mcu, Muc, Muu, Vc, Vu] = decompHndls(BFtoBFc, BFtoBFu)
%% decomposition handles for controllable and uncontrollable region
% This function creates function handles that decompose matrix and vector
% to its controllable and uncontrollable part.
% Msorted = [[Mcc(M), Mcu(M)]; [Muc(M), Muu(M)]]
% Vsorted = [Vc(V); Vu(V)]
% "sorted" means that the original matrix and vector are reordered into
% controllable / uncontrollable blocks.
%
% INPUTS
%  BFtoBFc: vector of indices of controllable basis functions, 
%           integer [1 x NBFc]
%  BFtoBFu: vector of indices of uncontrollable basis functions, 
%           integer [1 x NBFu]
%
% OUTPUTS
%  Mcc, Mcu, Muc, Muu: function handles for matrix, handle
%  Vc, Vu: function handles for vector, handle
%
% SYNTAX
% 
% [Mcc, Mcu, Muc, Muu, Vc, Vu] = decompHndls (BFtoBFc, BFtoBFu)
%     
% Included in AToM, info@antennatoolbox.com
% (c) 2020, Lukas Jelinek, CTU in Prague, lukas.jelinek@antennatoolbox.com
% mcode

Mcc = @(M) M(BFtoBFc, BFtoBFc);
Mcu = @(M) M(BFtoBFc, BFtoBFu);
Muc = @(M) M(BFtoBFu, BFtoBFc);
Muu = @(M) M(BFtoBFu, BFtoBFu);

Vc = @(m) m(BFtoBFc, :);
Vu = @(m) m(BFtoBFu, :);

end