function P = permMat(NBF, NBFc, NBFu, BFtoBFc, BFtoBFu)
% permutation matrix for controllable and uncontrollable region
% This function creates permutation matrices for controllable and
% uncontrollable region. Defining sorted vector as [Vc; Vu] and sorted
% matrix as [[Mcc; Mcu]; [Muc; Muu]] the following relations hold
% Vsort = P * V, V = inv(P) * Vsort, Msort = P * M * inv(P), inv(P) = P.'.
%
% INPUTS
%  NBF: total number of basis functions, integer [1 x 1]
%  NBFc: number of basis functions in controllable region, integer [1 x 1]
%  NBFu: number of basis functions in uncontrollable region, 
%        integer [1 x 1]
%  BFtoBFc: vector of indices of controllable basis functions, 
%           integer [1 x NBFc]
%  BFtoBFu: vector of indices of uncontrollable basis functions, 
%           integer [1 x NBFu]
%
% OUTPUTS
%  P: permutation matrix, double [NBF x NBF]
%
% SYNTAX
%
% [P] = permMat(NBF, NBFc, NBFu, BFtoBFc, BFtoBFu)
%
% Included in AToM, info@antennatoolbox.com
% (c) 2020, Lukas Jelinek, CTU in Prague, lukas.jelinek@antennatoolbox.com
% mcode

% allocation
P = zeros(NBF, NBF);

% controllable indices
for i1 = 1:NBFc
    P(i1, BFtoBFc(1, i1)) = 1;
end

% uncontrollable indices
for i1 = 1:NBFu
    P(NBFc + i1, BFtoBFu(1, i1)) = 1;
end

end