function [Gopt, Ivec, tocTime] = maxG(OP, varargin)
%% maxG - Optimal gain with power constraint
% This function maximizes gain constrained by power dissipation.
% Mathematicaly this function solves the following problem
% min { x'*(-OP.U)*x },
% s.t. { x'*(OP.R0 + OP.Rmat)*x + (-1) = 0 }.
%
%  INPUTS
%   OP: structure of matrix operators R0, Rmat, U
%   varargin: 'verbosity', reporting flag (false -> do not report - default,
%     true -> report)
%
%  OUTPUTS
%   Gopt: maximum of primar problem
%   Ivec: argmax vector
%   tocTime: duration of evaluation
%
%  SYNTAX
%
%   [Gopt, Ivec, tocTime] = maxG(OP)
%   [Gopt, Ivec, tocTime] = maxG(OP, varargin)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

% initialization
verbosity = 0;

if size(varargin,2) == 2 && strcmp(varargin{1}, 'verbosity')
   verbosity = varargin{2};
end

% evaluation
t0=tic;
[~, triplets] = solvers.normalizeTriplet( - OP.U, [], 0,...
    OP.R0 + OP.Rmat, [], 0);
[~, ~, Ivec] = solvers.QCQP.minAstB1(triplets{1}, triplets{4}, verbosity);
tocTime = toc(t0);

Gopt = 8*pi*real((Ivec'*OP.U*Ivec)/(Ivec'*(OP.Rmat + OP.R0)*Ivec));
end