function [WmOpt, Ivec, tocTime] = maxWm(OP, varargin)
%% maxWm - maximal inductance with power constraint
% This function maximize inductance constrained by capacitance and ohmic losses.
% Mathematicaly this function solves the following problem
% min { x'*(-OP.Xm)*x },
% s.t. { x'*(OP.Rmat + OP.Xe)*x + (-1) = 0 }.
%
%  INPUTS
%   OP: structure of matrix operators Xm, Xe, Rmat
%   varargin: 'verbosity', reporting flag (false -> do not report - default,
%     true -> report)
%
%  OUTPUTS
%   WmOpt: maximum of primar function
%   Ivec: argmax vector
%   tocTime: duration of evaluation
%
%  SYNTAX
%
%   [WmOpt, Ivec, tocTime] = maxWm(OP)
%   [WmOpt, Ivec, tocTime] = maxWm(OP, varargin)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

% initialization
verbosity = 0;

if size(varargin,2) == 2 && strcmp(varargin{1}, 'verbosity')
   verbosity = varargin{2};
end

% evaluation
t0=tic;
[~, ~, Ivec] = solvers.QCQP.minAstB1( - OP.Xm, OP.Rmat + OP.Xe, verbosity);
tocTime = toc(t0);

WmOpt = real((Ivec'*OP.Xm*Ivec)/(Ivec'*(OP.Rmat + OP.Xe)*Ivec)); % optimal value
end