function [dOpt, Ivec, tocTime] = minDelta(OP, varargin)
%% minDelta - Optimal Delta with power constraint
% This function minimizes dissipation factor constrained by ohmic losses.
% Mathematicaly this function solves the following problem
% min { x'*(-OP.R0)*x },
% s.t. { x'*OP.Rmat*x + (-1) = 0 }.
%
%  INPUTS
%   OP: structure of matrix operators R0, Rmat
%   varargin: 'verbosity', reporting flag (false -> do not report - default,
%     true -> report)
%
%  OUTPUTS
%   dOpt: minimum of primar problem
%   Ivec: argmin vector
%   tocTime: duration of evaluation
%
%  SYNTAX
%
%   [dOpt, Ivec, tocTime] = minDelta(OP)
%   [dOpt, Ivec, tocTime] = minDelta(OP, varargin)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

% initialization
verbosity = 0;

if size(varargin,2) == 2 && strcmp(varargin{1}, 'verbosity')
   verbosity = varargin{2};
end

% evaluation
t0=tic;
[~, triplets] = solvers.normalizeTriplet(- OP.R0, [], 0,...
    OP.Rmat, [], 0);
[~, ~, Ivec] = solvers.QCQP.minAstB1(triplets{1}, triplets{4}, verbosity);
tocTime = toc(t0);

dOpt = real((Ivec'*OP.Rmat*Ivec)/(Ivec'*OP.R0*Ivec)); % optimal value
end