 function [primarP, dualP, Ivec, lambda] = minLinStB1quad(a, alpha, B, beta)
%% minLinB1quad - Solve QCQP with quadrtic term in positive definite constraint
% This function solves quadratic program
% min {real(I'a) + alpha}
% s.t. {I'BI  + beta1  = 0}
% Matrix B1 is hermitian positive definite matrix.
%
%  INPUTS
%   a: vector [n x 1]
%   alpha: scalar
%   B: matrix [n x n]
%   beta: scalar
%
%  OUTPUTS
%   primarP: value of primar problem
%   dualP: value of dual problem
%   Ivec: argmin
%   lambda: optimal Lagrange's multipliers
%
%  SYNTAX
%
%   [primarP, dualP, Ivec, nu] = solvers.QCQP.minLinStB1quad(...
%     a, alpha, verbosity, varargin);
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

Binva = B\a;
lambda = - sqrt(real(a'*Binva)/(-4*beta));

Ivec = 1/(2*lambda)*Binva;
primarP = real(Ivec'*a) + alpha;
dualP = alpha - sqrt(real(-beta*a'*B*a));
end