function [C, c, gamma] = dFrac(A, a, alpha, B, b, beta, x0)
%% dFrac - second oder Taylor expansion of quadratic functions ratio
% The function exapnds ratio {0.5*x'*A*x + Re[x'*a] + alpha}/
% {0.5*x'*B*x + Re[x'*b] + beta} to Taylor polynomial of second order at point
% x0: x = x0 + h, {0.5*h'*C(x0)*h + Re[h'*c(x0)] + gamma(x0)}.
%
%   INPUTS:
%    A: hermitian matrix [n x n]
%    a: vector [n x 1]
%    alpha: scalar
%    B: hermitian matrix [n x n]
%    b: vector [n x 1]
%    beta: scalar
%    x0: point of expansion [n x 1]
%
%   OUTPUTS:
%    C: Hess matrix
%    c: gradient
%    gamma: scalar
%
%   SYNTAX
%
%    [C, c, gamma] = solvers.derivatives.dFrac(A, a, alpha, B, b, beta, x0)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode


% nominator expansion at x0
[A, a, alpha] = solvers.derivatives.fQuadTaylor(A, a, alpha, x0);

% denominator function expansion at x0
[B, b, beta] = solvers.derivatives.fQuadTaylor(B, b, beta, x0);

% denominator expasion
[B, b, beta] = solvers.derivatives.dPwr(B, b, beta, -1);

% multiplication expansion
[C, c, gamma] = solvers.derivatives.dMultiplication(A, a, alpha,...
    B, b, beta);
end