function [C, c, gamma] = dMultiplication(A, a, alpha, B, b, beta)
%% dMultInvers - function multiplication taylor expansion
% The function exapnds function multiplication
% {0.5*x'*A*x + Re[x'*a] + alpha}*{x'*B*x + Re[x'*b] + beta} to Taylor
% polynomial of second order {0.5*h'*C*h + Re[h'*c] + gamma}.
%
%   INPUTS:
%    A: Hess matrix [n x n]
%    a: gradient [n x 1]
%    alpha: scalar
%    B: hermitian matrix [n x n]
%    b: vector [n x 1]
%    beta: scalar
%    x0: point of expansion [n x 1]
%
%   OUTPUTS:
%    B: Hess matrix
%    b: gradient
%    beta: scalar
%
%   SYNTAX
%
%    [C, c, gamma] = solvers.derivatives.dMultiplication(A, a, alpha, B, b, beta)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

gamma = alpha*beta;
c = beta*a + alpha*b;
C = beta*A + alpha*B + 0.5*(b*a' + a*b'); % 0.5?
C = 0.5*(C + C');
end