function [B, b, beta] = dPwr(A, a, alpha, n)
%% dPwr - function power taylor expansion
% The function exapnds n-power (0.5*x'*A*x + Re[x'*a] + alpha)^n
% to Taylor polynomial of second order
% {0.5*h'*B*h + Re[h'*b] + beta}.
%
%   INPUTS:
%    A: Hess matrix [n x n]
%    a: gradient [n x 1]
%    alpha: scalar
%
%   OUTPUTS:
%    B: Hess matrix
%    b: gradient
%    beta: scalar
%
%   SYNTAX
%
%    [B, b, beta] = solvers.derivatives.dPwr(A, a, alpha, n)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

beta = alpha^n;
b = n*alpha^(n-1)*a;
B = 0.5*n*(n-1)*alpha^(n-2)*(a*a') + n*alpha^(n-1)*A;
end