function [Hess, grad, f0] = fQuadTaylor(A, a, alpha, x0)
%% fQuadTaylor - second oder Taylor expansion of quadratic function
% The function exapnds {x'*A*x + Re[x'*a] + alpha} to Taylor polynomial
% of second order at point x0: x = x0 + h,
% {0.5*h'*Hess(x0)*h + Re[h'*grad(x0)] + f0(x0)}.
%
%   INPUTS:
%    A: hermitian matrix [n x n]
%    a: vector [n x 1]
%    alpha: scalar
%    x0: point of expansion [n x 1]
%
%   OUTPUTS:
%    Hess: Hess matrix
%    grad: gradient
%    f0: scalar
%
%   SYNTAX
%
%    [Hess, grad, f0] = solvers.derivatives.fQuadTaylor(A, a, alpha, x0)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode


Hess = 2*A;
if isempty(A)
    grad = a;
    f0 = real(x0'*a + alpha);
elseif isempty(a)
    grad = 2*A*x0;
    f0 = real(x0'*A*x0 + alpha);
else
    grad = 2*A*x0 + a;
    f0 = real(x0'*A*x0 + x0'*a + alpha);
end
end