function grad = nGrad(f, x, type)
%% nGrad - numerical grdient
% The function evaluates numerically function gredient by central
% difference.
%
%   INPUTS:
%    f: function
%    x: point
%
%   OUTPUTS:
%    grad: gradient
%
%   SYNTAX
%
%    grad = solvers.derivatives.nGrad(f, x)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode


n = length(x);
grad = nan(n,1);

for ind = 1:n
    h = eps(x(ind))^(1/3); % optimal shifts
    
    x1 = x;
    x2 = x;
    
    x1(ind) = x(ind) - h;
    x2(ind) = x(ind) + h;
    
    fx1 = f(x1);
    fx2 = f(x2);
    
    if nargin > 2 && strcmp(type, 'complex')
        y1 = x;
        y2 = x;
        
        y1(ind) = x(ind) - 1i*h;
        y2(ind) = x(ind) + 1i*h;
        
        fy1 = f(y1);
        fy2 = f(y2);
    else
        fy1 = 0;
        fy2 = 0;
    end
    
    grad(ind) = (fx2 - fx1)/(2*h) + 1i*(fy2 - fy1)/(2*h);
end
end