function [flagLin, Tnorm, Icen, varargin] = centralize(varargin)
%% centralize - Centralize system according to first constraint
% This function transforms the coordinate system to place minimum of
% the positive definite constraint on the centre of the coordinate system.
% The transformation suppreses the linear term in the first constraint.
%
%   INPUTS:
%    varargin: triplets of matrix (2nd is PD), vector and scalar
%
%   OUTPUTS:
%    flagLin: true => transformed system contains liner terms, false =>
%       transformed system without linear terms
%    Tnorm: normalization matrix
%    Icen: position of the new coordinate origin centre
%    varargin: transformed triplets
%
%   SYNTAX
%
%    [flagLin, Icen, A, a, alpha, varargin] = solvers.centralize(...
%       A, a, alpha, varargin)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

Tnorm = inv(chol(varargin{4}));
Icen = -0.5*(Tnorm*(Tnorm'*varargin{5}));

nVarargin = length(varargin);
nConstr = nVarargin/3;

% linear term detection
flag_fun = @(Mat,vec) norm(vec)/norm(Mat) > 1e-12;

flagLin = false;

varargin =...
        controllableRegion.transformQuadFormAff(Icen, Tnorm, varargin{:});
ind = 1;
while ~flagLin && ind <= nConstr
    flagLin = flag_fun(varargin{3*(ind-1) + 1}, varargin{3*(ind-1) + 2})...
        || flagLin;
    ind = ind + 1;
end
end