function [norms, varargin] = normalizeTriplet(varargin)
%% normalizeTriplet - triplet normalization
% The fuinction divides all terms of triplet by the norm of matrix.
%
%   INPUTS:
%    varargin: triplets of matrix, vector and scalar
%
%   OUTPUTS:
%    norms: original norms of matrices
%    varargin: normalized triplets
%
%   SYNTAX
%
%    [M, m, m0, normM] = solvers.normalizeTriplet(M, m, m0)
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% © 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

nTrip = nargin/3;
norms = nan(1,nTrip);
for ind = 1:nTrip
    norms(ind) = norm(varargin{3*(ind - 1) + 1});
    if norms(ind) == 0
        warning('Matrix is full of zeros.');
    else
        for term = 1:3
        varargin{3*(ind - 1) + term} = varargin{3*(ind - 1) + term}./norms(ind);
        end
    end
end
end