%% exMaxG - example of use maxG
% This script provides example of use maxG function to maximize gain for
% given structure (patch 2:1) with dissipation matrix R0 + Rmat and directivity matrix U.
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

clc;
clear;
close all;

%% Mesh
Nx = 10;
Ny = 5;
PX = 2*ones(Ny, Nx);
[~, ~, mesh] = models.utilities.meshPublic.pixelGridToOrthoMesh(PX, 1);

%% MoM matrices
ka = 0.5; % electrical size
Zs = 0.01; % surface impedance

% smallest circumscribing sphere
a = models.utilities.meshPublic.getCircumsphere(mesh.nodes);

f = ka*models.utilities.constants.c0()/(2*pi*a); % frequaency
[OP, ~] = models.utilities.matrixOperators.MoM2D.batch.evaluate(mesh, f, Zs,...
   'normalize', true, 'symmetrize', true, 'quadOrder', 5,...
   'requests', {'R0', 'Rmat', 'U'}, 'usegpu', true); % get matrix operators
OP.U = OP.U_hndl(f, 0, 0, 'theta');

%% compute
[Gopt, Ivec, tocTime] = optimProblems.maxG(OP, 'verbosity', 1); % solve problem

disp(['Duration of evaluation: ', num2str(tocTime), ' s']);
disp(['Maximal gain is ', num2str(Gopt)]);

hndlCurrent = results.plotCurrent(mesh,...
   'basisFcns', OP.BF, 'Ivec', Ivec,...
   'part', 'abs', 'scale', 'linear', 'arrowScale', 'proportional');

hndlFarField = results.plotFarField('mesh', mesh,...
   'basisFcns', OP.BF, 'iVec', Ivec,...
   'frequency', f);

%% export figure
% hndlCurrent.type = 'current';
% export.plot2TikZ(hndlCurrent,...
%    'FileName','current_maxG');
% 
% hndlFarField.type = 'farField';
% export.plot2TikZ(hndlFarField,...
%     'Azimuth',60,...
%    'Elevation',30,...
%    'FileName','farField_maxG');