%% exMaxWm - example of use maxWm
% This stript provides example of use maxWm function to maximize inductance for
% given structure with matrix Xe + Rmat and directivity matrix Xm.
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2020, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

clc;
clear;
close all;

%% Mesh
Nx = 10;
Ny = 5;
PX = 2*ones(Ny, Nx);
[~, ~, mesh] = models.utilities.meshPublic.pixelGridToMesh(PX, 1);

%% MoM matrices
ka = 0.01; % electrical size
Zs = 0.01; % surface impedance

% smallest circumscribing sphere
a = models.utilities.meshPublic.getCircumsphere(mesh.nodes);

f = ka*models.utilities.constants.c0()/(2*pi*a); % frequaency
[OP, ~] = models.utilities.matrixOperators.MoM2D.batch.evaluate(mesh, f, Zs,...
   'normalize', true, 'symmetrize', true, 'quadOrder', 5,...
   'requests', {'Xm', 'Xe', 'Rmat'}, 'usegpu', true); % get matrix operators

%% compute
[WmOpt, Ivec, tocTime] = optimProblems.maxWm(OP, 'verbosity', 1); % solve problem

disp(['Duration of evaluation: ', num2str(tocTime), ' s']);
disp(['Maximal inductance is ', num2str(WmOpt)]);

hndlCurrent = results.plotCurrent(mesh,...
   'basisFcns', OP.BF, 'Ivec', Ivec,...
   'part', 'abs', 'scale', 'linear', 'arrowScale', 'proportional');