%% exMinDelta - example of use minDelta
% This stript provides example of use minDelta function to minimize dissipation
% factor for given structure with radiation matrix R0 and lossy matrix Rmat.
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

clc;
clear;
close all;

%% Mesh
Nx = 10;
Ny = 5;
PX = 2*ones(Ny, Nx);
[~, ~, mesh] = models.utilities.meshPublic.pixelGridToMesh(PX, 1);

%% MoM matrices
ka = 0.5; % electrical size
Zs = 0.01; % surface impedance

% smallest circumscribing sphere
a = models.utilities.meshPublic.getCircumsphere(mesh.nodes);

f = ka*models.utilities.constants.c0()/(2*pi*a); % frequaency
[OP, ~] = models.utilities.matrixOperators.MoM2D.batch.evaluate(mesh, f, Zs,...
   'normalize', true, 'symmetrize', true, 'quadOrder', 5,...
   'requests', {'R0', 'Rmat'}, 'usegpu', true); % get matrix operators

%% compute
% solve problem
[dOpt, Ivec, tocTime] = optimProblems.minDelta(OP, 'verbosity', 1);

disp(['Duration of evaluation: ', num2str(tocTime), ' s']);
disp(['Minimal dissipation factor: Z0/Zs*delta*(ka)^4 = ',...
    num2str(models.utilities.constants.Z0/Zs*dOpt*ka^4)]);

hndlCurrent = results.plotCurrent(mesh,...
   'basisFcns', OP.BF, 'Ivec', Ivec,...
   'part', 'abs', 'scale', 'linear', 'arrowScale', 'proportional');

%% export figure
% hndlCurrent.type = 'current';
% export.plot2TikZ(hndlCurrent,...
%    'FileName','current_minDelta');