%% exMinDeltaSelfRes - example of use minDeltaSelfRes
% This stript provides example of use minDeltaSelfres function to minimize
% selfresonat delta for given structure with radiantion matrix R0,
% lossy matrix Rmat and reactance matrix X0.
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

clc, clear, close all;

%% Mesh
Nx = 16;
Ny = 8;
PX = 2*ones(Ny, Nx);
[~, ~, mesh] = models.utilities.meshPublic.pixelGridToOrthoMesh(PX, 1);

%% MoM matrices
ka = 0.5; % electrical size
Zs = 0.01; % surface impedance

% smallest circumscribing sphere
a = models.utilities.meshPublic.getCircumsphere(mesh.nodes);

f = ka*models.utilities.constants.c0()/(2*pi*a); % frequency
[OP, ~] = models.utilities.matrixOperators.MoM2D.batch.evaluate(mesh, f, Zs,...
   'normalize', true, 'symmetrize', true, 'quadOrder', 7,...
   'requests', {'Rmat', 'X0', 'R0', 'Xmat'}, 'usegpu', true); % get matrix operators

%% compute
% solve problem
[deltaOpt, Ivec, lambdaVec, tocTime] = optimProblems.minDeltaSelfRes(OP,...
   'verbosity', 1);

disp(['Duration of evaluation: ', num2str(tocTime), ' s']);
disp(['Minimal selfresonant dissipation factor: Z0/Zs*delta*ka^4 = ',...
    num2str(deltaOpt*ka^4*models.utilities.constants.Z0/Zs)]);

hndlCurrent = results.plotCurrent(mesh,...
   'basisFcns', OP.BF, 'Ivec', Ivec,...
   'part', 'abs', 'scale', 'linear', 'arrowScale', 'proportional');

%% export figure
% hndlCurrent.type = 'current';
% export.plot2TikZ(hndlCurrent,...
%    'FileName','current_minDeltaSelfRes');