%% exMinQselfRes - example of use minQselfRes
% This stript provides example of use minQselfRes function to find lower
% bound on selfresonant Q for given structure (patch 2:1, 285 unknowns)
% with radiation matrix R0, reakctance matrix X0 and stored energy matrix omW.
%
% AToM package Fundamental Bounds, info@antennatoolbox.com
% (c) 2021, Jakub Liska, CTU in Prague, jakub.liska@antennatoolbox.com
% mcode

clc;
clear;
close all;

%% Mesh
Nx = 16;
Ny = 8;
PX = 2*ones(Ny, Nx);
[~, ~, mesh] = models.utilities.meshPublic.pixelGridToOrthoMesh(PX, 1);

%% MoM matrices
ka = 0.5; % electrical size
Zs = 0.01; % surface impedance

% smallest circumscribing sphere
a = models.utilities.meshPublic.getCircumsphere(mesh.nodes);

f = ka*models.utilities.constants.c0()/(2*pi*a); % frequaency
[OP, ~] = models.utilities.matrixOperators.MoM2D.batch.evaluate(mesh, f, Zs,...
   'normalize', true, 'symmetrize', true, 'quadOrder', 7,...
   'requests', {'R0', 'X0', 'omW', 'Xmat'}, 'usegpu', true); % get matrix operators

%% compute
[Qopt, Ivec, lambdaVec, tocTime] = optimProblems.minQselfRes(OP,...
   'lambdaVec', [0;0], 'verbosity', 1); % solve problem

disp(['Duration of evaluation: ', num2str(tocTime), ' s']);
disp(['Minimal selfresonant Q.ka^3 is ', num2str(Qopt*ka^3)]);

hndlCurrent = results.plotCurrent(mesh,...
   'basisFcns', OP.BF, 'Ivec', Ivec,...
   'part', 'abs', 'scale', 'linear', 'arrowScale', 'proportional');

%% export figure
hndlCurrent.type = 'current';
export.plot2TikZ(hndlCurrent,...
   'FileName','current_minQselfRes');